@@ -1,7 +1,7 @@
 /*
  * libev poll fd activity backend
  *
- * Copyright (c) 2007,2008 Marc Alexander Lehmann <libev@schmorp.de>
+ * Copyright (c) 2007 Marc Alexander Lehmann <libev@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
@@ -42,8 +42,6 @@
 void inline_size
 pollidx_init (int *base, int count)
 {
-  /* consider using memset (.., -1, ...), which is pratically guarenteed
-   * to work on all systems implementing poll */
   while (count--)
     *base++ = -1;
 }
@@ -89,11 +87,7 @@ static void
 poll_poll (EV_P_ ev_tstamp timeout)
 {
   struct pollfd *p;
-  int res;
-  
-  EV_RELEASE_CB;
-  res = poll (polls, pollcnt, (int)ceil (timeout * 1000.));
-  EV_ACQUIRE_CB;
+  int res = poll (polls, pollcnt, (int)ceil (timeout * 1000.));
 
   if (expect_false (res < 0))
     {
@@ -102,7 +96,7 @@ poll_poll (EV_P_ ev_tstamp timeout)
       else if (errno == ENOMEM && !syserr_cb)
         fd_enomem (EV_A);
       else if (errno != EINTR)
-        ev_syserr ("(libev) poll");
+        syserr ("(libev) poll");
     }
   else
     for (p = polls; res; ++p)
